@@ -6,7 +6,7 @@
     This script is a stand-alone application, and can be run from anywhere with a connection to the internet.
     It runs on either unix or windows.  It requires only the MadrigalWeb python module to be installed.
 
-$Id: globalDownload.py 7369 2021-04-22 17:55:08Z brideout $
+$Id: globalDownload.py 7454 2022-09-19 18:31:01Z brideout $
 """
 
 usage = """
@@ -573,7 +573,7 @@ for opt in optlist:
     elif opt[0] == '--user_affiliation':
         user_affiliation = opt[1]
     elif opt[0] == '--format':
-        format = opt[1].lower()
+        format = opt[1]
         if format == 'ascii':
             format = 'simple' # to match the api
     elif opt[0] == '--startDate':
@@ -634,8 +634,8 @@ if user_affiliation == None:
     print('--user_affiliation argument required - must your affiliation')
     sys.exit(0)
     
-if format not in ('simple', 'hdf5'):
-    print('--format must be given as either ascii or hdf5')
+if format not in ('simple', 'hdf5', 'netCDF4'):
+    print('--format must be given as either ascii, hdf5, or netCDF4, not <%s>' % (str(format)))
     sys.exit(0)
 
 # set startDate
